======
devenv
======


.. image:: https://img.shields.io/pypi/v/devenv.svg
        :target: https://pypi.python.org/pypi/devenv

.. image:: https://img.shields.io/travis/FlorianLudwig/devenv.svg
        :target: https://travis-ci.org/FlorianLudwig/devenv

.. image:: https://readthedocs.org/projects/devenv/badge/?version=latest
        :target: https://devenv.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/FlorianLudwig/devenv/shield.svg
     :target: https://pyup.io/repos/github/FlorianLudwig/devenv/
     :alt: Updates


A development environment based upon docker.


* Free software: Apache Software License 2.0
* Documentation: https://devenv.readthedocs.io.

Pre-Requirements
----------------

* docker installed and running
* the user you use to develop must have access to docker

TODO, ideas and vision
----------------------

 * git integration
 * ci integration (gitlab, travis, jenkins, ...)
 * IDE integration (atom, intellij/pycharm)
 * `langserv integration<http://langserver.org/>`_
 * rpm and deb packages

Inspirations
------------

* `vagrant<https://www.vagrantup.com/>`_
* `cage<https://github.com/faradayio/cage>`_
